#!/usr/bin/env python3

import argparse
import sys
from pathlib import Path
from tree import SourceNode
from mparse import create_markdown_parser

# The command line parser
parser = argparse.ArgumentParser(prog='dragonglass')
parser.add_argument('source_dir')
parser.add_argument('dest_dir')


def main():
    args = parser.parse_args()

    source_dir = Path(args.source_dir).resolve()
    if not (source_dir.exists() and source_dir.is_dir()):
        print(f"{source_dir} is not a valid directory")
        return 1

    dest_dir = Path(args.dest_dir).resolve()
    if dest_dir.exists() and not dest_dir.is_dir():
        print(f"{dest_dir} exists but is not a valid directory")
        return 1

    nodes = SourceNode.generate_list(source_dir)
    for node in nodes:
        node.load_metadata(source_dir)

    mdparse = create_markdown_parser()
    for node in nodes:
        node.parse_markdown(source_dir, mdparse)

    # TEMP
    for node in nodes:
        print(node)
        if node.metadata:
            print(f"Metadata: {node.metadata}")
        if node.text:
            print("----- BEGIN TEXT -----")
            print(node.text)
            print("------ END TEXT ------")

    return 0


if __name__ == '__main__':
    sys.exit(main())
