#/usr/bin/env python3

import markdown
import xml.etree.ElementTree as etree
from markdown.extensions import Extension
from markdown.inlinepatterns import InlineProcessor, SimpleTagInlineProcessor
from markdown.preprocessors import Preprocessor


class MetaStripper(Extension):

    class MetaStripperProc(Preprocessor):
        def run(self, lines):
            if lines[0] == '---':
                lines.pop(0)
                while lines[0] != '---':
                    lines.pop(0)
                lines.pop(0)
            return lines

    def extendMarkdown(self, md):
        md.preprocessors.register(MetaStripper.MetaStripperProc(md), 'metastripper', 0)


class ObsidianLinks(Extension):

    class ObsidianLinksProc(InlineProcessor):
        def __init__(self, pattern, md):
            super(ObsidianLinks.ObsidianLinksProc, self).__init__(pattern, md)

        def parse_reference(self, contents):
            text = None
            t = contents.split('|')
            if len(t) > 1:
                text = t[1]
                contents = t[0]
            if not text:
                text = contents
            return contents, text

        def handleMatch(self, m, data):
            link, text = self.parse_reference(m.group(0)[2:-2])
            el = etree.Element('a')
            el.set('href', link)
            el.text = text
            return el, m.start(0), m.end(0)

    def extendMarkdown(self, md):
        OBSLINK_PATTERN = r'\[\[(.*?)\]\]'
        md.inlinePatterns.register(ObsidianLinks.ObsidianLinksProc(OBSLINK_PATTERN, md), 'obsidian_links', 0)


class Strikeout(Extension):
    def extendMarkdown(self, md):
        md.inlinePatterns.register(SimpleTagInlineProcessor(r'()~~(.*?)~~', 'del'), 'strikeout', 0)


class Highlight(Extension):
    def extendMarkdown(self, md):
        md.inlinePatterns.register(SimpleTagInlineProcessor(r'()\=\=(.*?)\=\=', 'ins'), 'highlight', 0)


def create_markdown_parser():
    return markdown.Markdown(extensions=[MetaStripper(), ObsidianLinks(), Strikeout(), Highlight()])
